@@ -303,6 +303,16 @@ bbb
         ml = list(m3.merge_lines('LAO', 'TAO'))
         self.assertEqual(ml, MERGED_RESULT)
 
+    def test_merge_poem_bytes(self):
+        """Test case from diff3 manual"""
+        m3 = merge3.Merge3(
+            [line.encode() for line in TZU],
+            [line.encode() for line in LAO],
+            [line.encode() for line in TAO])
+        ml = list(m3.merge_lines('LAO', 'TAO'))
+        self.assertEqual(
+            ml, [line.encode() for line in MERGED_RESULT])
+
     def test_minimal_conflicts_common(self):
         """Reprocessing"""
         base_text = ("a\n" * 20).splitlines(True)
